#[non_exhaustive]pub struct ListNamedQueriesOutput {
pub named_query_ids: Option<Vec<String>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.named_query_ids: Option<Vec<String>>The list of unique query IDs.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListNamedQueriesOutput
impl ListNamedQueriesOutput
Sourcepub fn named_query_ids(&self) -> &[String]
pub fn named_query_ids(&self) -> &[String]
The list of unique query IDs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .named_query_ids.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListNamedQueriesOutput
impl ListNamedQueriesOutput
Sourcepub fn builder() -> ListNamedQueriesOutputBuilder
pub fn builder() -> ListNamedQueriesOutputBuilder
Creates a new builder-style object to manufacture ListNamedQueriesOutput.